@@ -16,7 +16,7 @@ import nbclassic
 from nbclassic import (
     DEFAULT_STATIC_FILES_PATH,
     DEFAULT_TEMPLATE_PATH_LIST,
-    url_prefix_notebook
+    nbclassic_path
 )
 
 from nbclassic._version import __version__
@@ -118,7 +118,7 @@ class NotebookApp(
     extension_url = "/tree"
     subcommands = {}
 
-    default_url = Unicode("%s/tree" % url_prefix_notebook()).tag(config=True)
+    default_url = Unicode("%s/tree" % nbclassic_path()).tag(config=True)
 
     # Override the default open_Browser trait in ExtensionApp,
     # setting it to True.
@@ -153,11 +153,6 @@ class NotebookApp(
                 DEFAULT_STATIC_FILES_PATH)
         ]
 
-    @property
-    def template_file_path(self):
-        """return extra paths + the default locations"""
-        return self.extra_template_paths + DEFAULT_TEMPLATE_PATH_LIST
-
     extra_nbextensions_path = List(Unicode(), config=True,
                                    help=_i18n(
                                        """extra paths to look for Javascript notebook extensions""")
@@ -169,21 +164,15 @@ class NotebookApp(
         path = self.extra_nbextensions_path + jupyter_path('nbextensions')
         return path
 
-    # Local path to static files directory.
-    static_paths = [DEFAULT_STATIC_FILES_PATH]
-
-    # Local path to templates directory.
-    template_paths = DEFAULT_TEMPLATE_PATH_LIST
-
     @property
     def static_paths(self):
         """Rename trait in jupyter_server."""
-        return [DEFAULT_STATIC_FILES_PATH]
+        return self.extra_static_paths  + [DEFAULT_STATIC_FILES_PATH]
 
     @property
     def template_paths(self):
         """Rename trait for Jupyter Server."""
-        return DEFAULT_TEMPLATE_PATH_LIST
+        return self.extra_template_paths + DEFAULT_TEMPLATE_PATH_LIST
 
     def _prepare_templates(self):
         super(NotebookApp, self)._prepare_templates()
@@ -194,7 +183,7 @@ class NotebookApp(
         nbui = gettext.translation('nbui', localedir=os.path.join(
             base_dir, 'nbclassic/i18n'), fallback=True)
         self.jinja2_env.install_gettext_translations(nbui, newstyle=False)
-        self.jinja2_env.globals.update(base_url_prefix=url_prefix_notebook)
+        self.jinja2_env.globals.update(nbclassic_path=nbclassic_path)
 
     def _link_jupyter_server_extension(self, serverapp):
         # Monkey-patch Jupyter Server's and nbclassic's static path list to include
@@ -274,6 +263,16 @@ class NotebookApp(
                 {"url": self.serverapp.base_url+"files/{0}"}
             )
         )
+        # Add a redirect from /nbclassic to /nbclassic/tree
+        # if both notebook>=7 and nbclassic are installed.
+        if len(nbclassic_path()) > 0:
+            handlers.append(
+                (
+                    rf"/nbclassic",
+                    RedirectHandler,
+                    {"url": self.serverapp.base_url+"nbclassic/tree"}
+                )
+            )
 
         # load extra services specified by users before default handlers
         for service in self.settings['extra_services']:
